<?php

namespace App\Filament\Resources\VehiclesResource\RelationManagers;

use Filament\Forms;
use Filament\Resources\Form;
use Filament\Resources\RelationManagers\RelationManager;
use Filament\Resources\Table;
use Filament\Tables;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class VehicleOwnerRelationManager extends RelationManager
{
    protected static string $relationship = 'vehicleOwner';

    protected static ?string $recordTitleAttribute = 'owner';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('bidder_assigned_number')
                    ->label('Number')
                    ->required()
                    ->createOptionForm([
                        Forms\Components\TextInput::make('bidder_fname')->label('First Name'),
                        Forms\Components\TextInput::make('bidder_lname')->label('Last Name'),
                        Forms\Components\TextInput::make('bidder_addr')->label('Address'),
                        Forms\Components\TextInput::make('bidder_city')->label('City'),
                        Forms\Components\TextInput::make('bidder_state')->label('State'),
                        Forms\Components\TextInput::make('bidder_zip')->label('Zip'),
                        Forms\Components\TextInput::make('bidder_phone')->label('Phone Number'),
                        Forms\Components\TextInput::make('bidder_email')->label('Email'),
                        Forms\Components\TextInput::make('bidder_assigned_number')->label('Assigned Number'),
                    ]),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('bidder_fname')->label('First Name'),
                Tables\Columns\TextColumn::make('bidder_lname')->label('Last Name'),
                Tables\Columns\TextColumn::make('bidder_assigned_number')->label('Number'),
            ])
            ->filters([
                //
            ])
            ->headerActions([
                Tables\Actions\CreateAction::make(),
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
                Tables\Actions\DeleteAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\DeleteBulkAction::make(),
            ]);
    }    
}
